
pub enum HostEvent<'a> {
	Midi {
		data: [u8; 3],
		delta_frames: i32,
		live: bool,
		note_length: Option<i32>,
		note_offset: Option<i32>,
		detune: i8,
		note_off_velocity: u8,
	},
	SysEx {
		payload: &'a [u8],
		delta_frames: i32,
	},
}

pub trait HostInterface {
	fn get_host_name(&self) -> String;
	fn get_host_version(&self) -> String;
	fn get_host_vendor(&self) -> String;


	fn set_parameter(&mut self, index: i32, value: f32);
	fn get_parameter(&self, index: i32) -> f32;

	fn process_f32(&mut self, input: Vec<&mut [f32]>, output: Vec<&mut [f32]>);
	fn process_f64(&mut self, input: Vec<&mut [f64]>, output: Vec<&mut [f64]>);
	fn process_events(&mut self, events: Vec<HostEvent>);

	fn open_editor(&mut self);
	fn close_editor(&mut self);
	fn is_editor_open(&self) -> bool;
	fn has_editor(&mut self) -> bool;
}
